==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V7/CampaignManagementService/CashBackInfo.pm <==
package Microsoft::AdCenter::V7::CampaignManagementService::CashBackInfo;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::V7::CampaignManagementService::CashBackInfo - Represents "CashBackInfo" in Microsoft AdCenter Campaign Management Service.

=cut

sub _type_name {
    return 'CashBackInfo';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v7';
}

our @_attributes = (qw/
    CashBackAmount
    CashBackStatus
    CashBackText
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    CashBackAmount => 'double',
    CashBackStatus => 'CashBackStatus',
    CashBackText => 'string',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    CashBackAmount => 0,
    CashBackStatus => 0,
    CashBackText => 0,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 CashBackAmount

Gets/sets CashBackAmount (double)

=head2 CashBackStatus

Gets/sets CashBackStatus (CashBackStatus)

=head2 CashBackText

Gets/sets CashBackText (string)

=cut

==> Microsoft-AdCenter-8.03.tar.gz: Microsoft-AdCenter-8.03/lib/Microsoft/AdCenter/V7/CampaignManagementService/CashBackInfo.pm <==
package Microsoft::AdCenter::V7::CampaignManagementService::CashBackInfo;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::V7::CampaignManagementService::CashBackInfo - Represents "CashBackInfo" in Microsoft AdCenter Campaign Management Service.

=cut

sub _type_name {
    return 'CashBackInfo';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v7';
}

our @_attributes = (qw/
    CashBackAmount
    CashBackStatus
    CashBackText
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    CashBackAmount => 'double',
    CashBackStatus => 'CashBackStatus',
    CashBackText => 'string',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    CashBackAmount => 0,
    CashBackStatus => 0,
    CashBackText => 0,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 CashBackAmount

Gets/sets CashBackAmount (double)

=head2 CashBackStatus

Gets/sets CashBackStatus (CashBackStatus)

=head2 CashBackText

Gets/sets CashBackText (string)

=cut
